<template>
  <el-dialog
    :visible.sync="dialogVisible"
    @close="$emit('close-dialog')"
    @closed="closed"
    @open="open"
    title="转单申请"
    width="1200px"
    top="15vh"
  >
    <el-form
      ref="editForm"
      :rules="rules"
      :model="formData"
      label-width="120px"
      label-suffix=":"
    >
      <public-title title="巡检计划信息" />
      <el-row>
        <el-col :span="12">
          <el-form-item label="设备名称" prop="name">
            <el-input
              :clearable="false"
              v-model="formData.name"
              readonly
              disabled
              placeholder="-"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="所属区域" prop="areaName">
            <el-input
              :clearable="false"
              v-model="formData.areaName"
              readonly
              disabled
              placeholder="-"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="巡查时间" prop="inspectionTime">
            <el-date-picker
              disabled
              type="date"
              value-format="yyyy-MM-dd"
              style="width:100%"
              v-model="formData.inspectionTime"
              :clearable="false"
              placeholder="-"
            ></el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="详细地址" prop="address">
            <el-input
              :clearable="false"
              v-model="formData.address"
              disabled
              placeholder="-"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="巡查人员姓名" prop="inspectionName">
            <el-input
              disabled
              :clearable="false"
              v-model="formData.inspectionName"
              placeholder="-"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="巡查人员电话" prop="inspectionPhone">
            <el-input
              disabled
              :clearable="false"
              v-model="formData.inspectionPhone"
              placeholder="-"
            />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="故障描述" prop="description">
            <el-input
              :clearable="false"
              placeholder="-"
              v-model="formData.description"
              type="textarea"
              :autosize="{ minRows: 1, maxRows: 2}"
              disabled
            />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row v-if="formData.inspectionImgUrlArray.length">
        <el-col :span="24">
          <el-form-item label="巡检图片" prop="inspectionImgUrlArray">
            <el-upload
              name="files"
              action=""
              disabled
              :file-list="formData.inspectionImgUrlArray"
              list-type="picture-card"
              class="inspectionImg"
            >
              <i slot="default" class="el-icon-plus" />
            </el-upload>
          </el-form-item>
        </el-col>
      </el-row>
      <public-title title="派遣人员信息" />
      <el-row>
        <el-col :span="12">
          <el-form-item label="派遣人员姓名" prop="linkName">
            <el-input
              :clearable="false"
              placeholder="-"
              v-model="formData.linkName"
              readonly
              class="readonly-input"
              disabled
            />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="派遣人员电话" prop="linkPhone">
            <el-input
              :clearable="false"
              placeholder="-"
              v-model="formData.linkPhone"
              readonly
              class="readonly-input"
              disabled
            />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="维修开始时间" prop="startTime">
            <el-date-picker
              type="date"
              value-format="yyyy-MM-dd"
              style="width:100%"
              placeholder="-"
              v-model="formData.startTime"
              disabled
            ></el-date-picker>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="维修结束时间" prop="endTime">
            <el-date-picker
              type="date"
              value-format="yyyy-MM-dd"
              style="width:100%"
              placeholder="-"
              v-model="formData.endTime"
              disabled
            ></el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="转单原因" prop="reasonTransfer">
            <el-input
              :clearable="false"
              placeholder="请输入转单原因"
              v-model="formData.reasonTransfer"
              type="textarea"
              :autosize="{ minRows: 1, maxRows: 2}"
            />
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>

    <template v-slot:footer>
      <el-button
        type="primary"
        @click="handleSaveData"
      >
        申 请
      </el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>

  </el-dialog>
</template>

<script>
import {
  workOrderDetails,
  workOrderReversal
} from '@/api/device/resourceInspection/maintenanceRepair'
import PublicTitle from '../PublicTitle/index.vue'

export default {
  name: 'TransferOrderDialog',
  components: {PublicTitle},
  props: {
    isShowDialog: {
      default: false,
      type: Boolean
    },
    rowInfo: {
      default: () => ({}),
      type: Object
    }
  },
  computed: {
    dialogVisible: {
      get() {
        return this.isShowDialog
      },
      set(val) {
        this.$emit('update:isShowDialog', val)
      }
    },
    previewUrl() {
      return window.context.portal + '/file/onlinePreviewController/v1/getFileById_'
    }
  },
  data() {
    return {
      formData: {
        inspectionImgUrlArray: []
      },
      rules: {
        name: [
          {required: false, message: '设备名称不能为空', trigger: 'change'}
        ],
        linkName: [
          {required: false, message: '维修人员姓名不能为空', trigger: 'change'}
        ],
        linkPhone: [
          {required: false, message: '维修人员电话不能为空', trigger: 'change'}
        ],
        startTime: [
          {required: false, message: '维修开始时间不能为空', trigger: 'change'}
        ],
        endTime: [
          {required: false, message: '维修结束时间不能为空', trigger: 'change'}
        ],
        reasonTransfer: [
          {required: true, message: '转单原因不能为空', trigger: 'change'}
        ]
      },
      departmentList: [], // 设备列表
      userSelectDialog: false, // 人员选择弹层显隐
      userName: ''
    }
  },
  created() {
  },
  methods: {
    // 弹层打开
    open() {
      if (this.rowInfo.id) this.getResultDetails(this.rowInfo.id)
    },

    // 弹层关闭
    closed() {
      this.formData = this.$options.data().formData
      this.$refs.editForm.resetFields()
    },

    // 获取详情
    async getResultDetails(id) {
      let {inspectionImgUrl, ...formData} = (await workOrderDetails(id))?.value || {}
      this.formData = {
        ...formData,
        inspectionImgUrl,
        inspectionImgUrlArray: (inspectionImgUrl?.split() || []).flatMap(id => {
          return !id ? [] : {
            url: this.previewUrl + id,
            fileId: id
          }
        })
      }
      this.$refs.editForm.resetFields()
    },

    // 保存
    handleSaveData() {
      this.$refs.editForm.validate(async (valid, object) => {
        if (!valid) {
          this.$message.warning(`有${Object.keys(object).length}个字段未通过校验，请正确填写表单内容。`)
        } else {
          const {toexamain, ...formData} = this.formData
          const {state} = await workOrderReversal({
            ...formData,
            toexamain: '5'
          })
          if (state) {
            this.$message.success(`转单申请成功`)
            this.dialogVisible = false
            this.$emit('closeDialog', 'TransferOrderDialog')
          } else {
            this.$message.error(`转单申请失败`)
          }
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
::v-deep .el-dialog__body {
  padding-top: 15px;

  .readonly-input {

    .el-input__inner {
      cursor: pointer;
    }
  }

  .el-upload-list__item, .el-upload {
    width: 100px;
    height: 100px;
    line-height: 100px;
  }

  .inspectionImg {
    .el-upload {
      display: none;
    }
  }
}
</style>
